==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnToggledEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnToggledEventArgsDetailDescriptionMetadata } from "./WebColumnToggledEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDescription } from "./WebColumnToggledEventArgsDescription";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnToggledEventArgsDescriptionMetadata, _super);
    function WebColumnToggledEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnToggledEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnToggledEventArgsDescriptionMetadata.a == null) {
            WebColumnToggledEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnToggledEventArgsDescriptionMetadata.c(WebColumnToggledEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnToggledEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnToggledEventArgsDescriptionMetadata.a);
        WebColumnToggledEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnToggledEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnToggledEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebColumnToggledEventArgsDetail");
    };
    WebColumnToggledEventArgsDescriptionMetadata.d = function (a) {
        WebColumnToggledEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnToggledEventArgs", function () { return new WebColumnToggledEventArgsDescription(); });
        a.z("WebColumnToggledEventArgs", WebColumnToggledEventArgsDescriptionMetadata.a);
    };
    WebColumnToggledEventArgsDescriptionMetadata.$t = markType(WebColumnToggledEventArgsDescriptionMetadata, 'WebColumnToggledEventArgsDescriptionMetadata');
    WebColumnToggledEventArgsDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDescriptionMetadata;
}(Base));
export { WebColumnToggledEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnToggledEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnToggledEventArgsDetailDescriptionMetadata } from "./WebColumnToggledEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDescription } from "./WebColumnToggledEventArgsDescription";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnToggledEventArgsDescriptionMetadata, _super);
    function WebColumnToggledEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnToggledEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnToggledEventArgsDescriptionMetadata.a == null) {
            WebColumnToggledEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnToggledEventArgsDescriptionMetadata.c(WebColumnToggledEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnToggledEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnToggledEventArgsDescriptionMetadata.a);
        WebColumnToggledEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnToggledEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnToggledEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnToggledEventArgsDetail");
    };
    WebColumnToggledEventArgsDescriptionMetadata.d = function (a) {
        WebColumnToggledEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnToggledEventArgs", function () { return new WebColumnToggledEventArgsDescription(); });
        a.ab("WebColumnToggledEventArgs", WebColumnToggledEventArgsDescriptionMetadata.a);
    };
    WebColumnToggledEventArgsDescriptionMetadata.$t = markType(WebColumnToggledEventArgsDescriptionMetadata, 'WebColumnToggledEventArgsDescriptionMetadata');
    WebColumnToggledEventArgsDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDescriptionMetadata;
}(Base));
export { WebColumnToggledEventArgsDescriptionMetadata };
